==> aria2_0.9.0.orig.tar.gz: aria2-0.9.0/src/Segment.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_SEGMENT_H_
#define _D_SEGMENT_H_

#include "common.h"
#include <deque>

using namespace std;

class Segment {
public:
  int index;
  int length;
  int segmentLength;
  int writtenLength;

  Segment(int index, int length, int segmentLength, int writtenLength = 0)
    :index(index), length(length), segmentLength(segmentLength),
     writtenLength(writtenLength) {}

  Segment():index(-1), length(0), segmentLength(0), writtenLength(0) {}

  bool complete() const {
    return length <= writtenLength;
  }

  bool isNull() const {
    return index == -1;
  }

  long long int getPosition() const {
    return ((long long int)index)*segmentLength;
  }

  bool operator==(const Segment& segment) const {
    return index == segment.index &&
      length == segment.length &&
      segmentLength == segment.segmentLength &&
      writtenLength == segment.writtenLength;
  }

  bool operator!=(const Segment& segment) const {
    return !(*this == segment);
  }

  friend ostream& operator<<(ostream& o, const Segment& segment);
};

ostream& operator<<(ostream& o, const Segment& segment);

#endif // _D_SEGMENT_H_

==> aria2_0.11.0.orig.tar.gz: aria2-0.11.0/src/Segment.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_SEGMENT_H_
#define _D_SEGMENT_H_

#include "common.h"
#include <deque>

using namespace std;

class Segment {
public:
  int index;
  int length;
  int segmentLength;
  int writtenLength;

  Segment(int index, int length, int segmentLength, int writtenLength = 0)
    :index(index), length(length), segmentLength(segmentLength),
     writtenLength(writtenLength) {}

  Segment():index(-1), length(0), segmentLength(0), writtenLength(0) {}

  bool complete() const {
    return length <= writtenLength;
  }

  bool isNull() const {
    return index == -1;
  }

  int64_t getPosition() const {
    return ((int64_t)index)*segmentLength;
  }

  int64_t getPositionToWrite() const
  {
    return getPosition()+writtenLength;
  }

  bool operator==(const Segment& segment) const {
    return index == segment.index &&
      length == segment.length &&
      segmentLength == segment.segmentLength &&
      writtenLength == segment.writtenLength;
  }

  bool operator!=(const Segment& segment) const {
    return !(*this == segment);
  }

  friend ostream& operator<<(ostream& o, const Segment& segment);
};

ostream& operator<<(ostream& o, const Segment& segment);

typedef SharedHandle<Segment> SegmentHandle;

#endif // _D_SEGMENT_H_
